package letter;

import java.awt.Color;
import java.awt.FlowLayout;
import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;
import java.util.ArrayList;
import java.util.Collections;

import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JTextArea;

public class Logger extends JFrame implements KeyListener {

    private class Pair implements Comparable<Pair> {
        public char c;
        public int freq;
        public Pair(char c, int freq) { 
            this.c = c;
            this.freq = freq;
        }
        public int compareTo(Pair other) {
            if (freq > other.freq) return -1;
            else if (freq == other.freq) return 0;
            else return 1;
        }
    }
    
    private JTextArea top;
    private JLabel current;
    private ArrayList<Pair> tally;
    
    public Logger() {
        super();
        setSize(100, 150);
        setLocation(400, 400);
        
        tally = new ArrayList<Pair>();
        
        top = new JTextArea(5, 10);
        top.setEditable(false);
        current = new JLabel();
        current.setForeground(Color.RED);
        
        setLayout(new FlowLayout());
        add(top);
        add(current);
        
        setDefaultCloseOperation(EXIT_ON_CLOSE);
        setVisible(true);
        
    }
    
    public void keyPressed(KeyEvent e) {
        current.setText(e.getKeyChar() + "");
    }

    public void keyReleased(KeyEvent e) {
        current.setText("");
    }

    public void keyTyped(KeyEvent e) {
        char c = e.getKeyChar();
        if ((c >= 'a' && c <= 'z') || (c >='A' && c <= 'Z')) {
            if (c >='A' && c <= 'Z')
                c = (char) (c - 'A' + 'a');
            if (! tryToIncrement(c))
                tally.add(new Pair(c, 1));
            Collections.sort(tally);
            String report = "";
            int i = 0;
            for (Pair p : tally) {
                report += p.c + " " + p.freq;
                i++;
                if (i >= 5) break;
                report += "\n";
            }
            top.setText(report);
        }
    }

    private boolean tryToIncrement(char c) {
        for (Pair p  : tally) 
            if (p.c == c) {
                p.freq++;
                
                return true;
            }
        return false;
    }
    

    public static void main(String[] args) {
        Logger log = new Logger();
        log.setFocusable(true);
        log.addKeyListener(log);
    }
    
    
}
